@@ -10,5 +10,5 @@ class TestPackage(unittest.TestCase):
     def testImport(self):
         path = os.path.dirname(tfkit.__file__)
         print(path)
-        tfkit.model_loader
+        tfkit.model
         tfkit.utility
